import svelte from 'rollup-plugin-svelte';
import resolve from 'rollup-plugin-node-resolve';
import commonjs from 'rollup-plugin-commonjs';
import livereload from 'rollup-plugin-livereload';
import { terser } from 'rollup-plugin-terser';

const production = !process.env.ROLLUP_WATCH;

export default {
    input: 'src/main.js',
    output: {
        sourcemap: true,
        format: 'iife',
        name: 'app',
        file: 'public/bundle.js'
    },
    plugins: [
        svelte({
            dev: !production,
            css: css => css.write('public/bundle.css')
        }),

        resolve({
            browser: true,
            dedupe: importee => importee === 'svelte'
                 || importee.startsWith('svelte/')
        }),

        commonjs(),

        // In development mode, watch the `public` directory
        // and refresh the browser on changes
        !production && livereload('public'),

        // In production, minify
        production && terser()
    ],
    watch: {
        chokidar: false,
        clearScreen: false
    }
};
